
SIDEBAR = 'SIDEBAR'
TABBED = 'TABBED'
INLINE = 'INLINE'
HIDDEN = 'HIDDEN'

FONTWEIGHT_THIN = 100
FONTWEIGHT_EXTRALIGHT = 200
FONTWEIGHT_LIGHT = 300
FONTWEIGHT_NORMAL = 400
FONTWEIGHT_MEDIUM = 500
FONTWEIGHT_SEMIBOLD = 600
FONTWEIGHT_BOLD = 700
FONTWEIGHT_EXTRABOLD = 800
FONTWEIGHT_HEAVY = 900
FONTWEIGHT_EXTRAHEAVY = 1000
