print("import: 'gooey'")
import gooey

print("import: 'gooey.gui'")
import gooey.gui

print("import: 'gooey.gui.components'")
import gooey.gui.components

print("import: 'gooey.gui.components.layouts'")
import gooey.gui.components.layouts

print("import: 'gooey.gui.components.widgets'")
import gooey.gui.components.widgets

print("import: 'gooey.gui.components.widgets.core'")
import gooey.gui.components.widgets.core

print("import: 'gooey.gui.components.widgets.dialogs'")
import gooey.gui.components.widgets.dialogs

print("import: 'gooey.gui.containers'")
import gooey.gui.containers

print("import: 'gooey.gui.lang'")
import gooey.gui.lang

print("import: 'gooey.gui.util'")
import gooey.gui.util

print("import: 'gooey.images'")
import gooey.images

print("import: 'gooey.languages'")
import gooey.languages

print("import: 'gooey.python_bindings'")
import gooey.python_bindings

print("import: 'gooey.tests'")
import gooey.tests

print("import: 'gooey.util'")
import gooey.util

